@@ -1,7 +1,7 @@
 package App::lcpan::Cmd::gh_clone;
 
-our $DATE = '2017-01-20'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $DATE = '2017-01-23'; # DATE
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use strict;
@@ -30,12 +30,26 @@ $SPEC{handle_cmd} = {
 };
 sub handle_cmd {
     my %args = @_;
-    my $dist = $args{dist};
 
     my $state = App::lcpan::_init(\%args, 'ro');
     my $dbh = $state->{dbh};
 
-    my $res = App::lcpan::Cmd::dist_meta::handle_cmd(%args);
+    my ($dist, $file_id);
+    {
+        # first find dist
+        if (($file_id) = $dbh->selectrow_array(
+            "SELECT file_id FROM dist WHERE name=? AND is_latest", {}, $args{module_or_dist})) {
+            $dist = $args{module_or_dist};
+            last;
+        }
+        # try mod
+        if (($file_id, $dist) = $dbh->selectrow_array("SELECT m.file_id, d.name FROM module m JOIN dist d ON m.file_id=d.file_id WHERE m.name=?", {}, $args{module_or_dist})) {
+            last;
+        }
+    }
+    $file_id or return [404, "No such module/dist '$args{module_or_dist}'"];
+
+    my $res = App::lcpan::Cmd::dist_meta::handle_cmd(%args, dist=>$dist);
     return [412, $res->[1]] unless $res->[0] == 200;
     my $meta = $res->[2];
 
@@ -68,7 +82,7 @@ App::lcpan::Cmd::gh_clone - Clone github repo of a dist
 
 =head1 VERSION
 
-This document describes version 0.002 of App::lcpan::Cmd::gh_clone (from Perl distribution App-lcpan-CmdBundle-gh), released on 2017-01-20.
+This document describes version 0.003 of App::lcpan::Cmd::gh_clone (from Perl distribution App-lcpan-CmdBundle-gh), released on 2017-01-23.
 
 =head1 DESCRIPTION
 
