@@ -1,7 +1,7 @@
 package App::lcpan::Cmd::gh_open;
 
-our $DATE = '2017-01-20'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $DATE = '2017-01-23'; # DATE
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use strict;
@@ -15,20 +15,34 @@ our %SPEC;
 
 $SPEC{handle_cmd} = {
     v => 1.1,
-    summary => 'Open the GitHub project page of a dist',
+    summary => 'Open the GitHub project page of a module/dist',
     args => {
         %App::lcpan::common_args,
-        %App::lcpan::dist_args,
+        %App::lcpan::mod_or_dist_args,
     },
 };
 sub handle_cmd {
     my %args = @_;
-    my $dist = $args{dist};
 
     my $state = App::lcpan::_init(\%args, 'ro');
     my $dbh = $state->{dbh};
 
-    my $res = App::lcpan::Cmd::dist_meta::handle_cmd(%args);
+    my ($dist, $file_id);
+    {
+        # first find dist
+        if (($file_id) = $dbh->selectrow_array(
+            "SELECT file_id FROM dist WHERE name=? AND is_latest", {}, $args{module_or_dist})) {
+            $dist = $args{module_or_dist};
+            last;
+        }
+        # try mod
+        if (($file_id, $dist) = $dbh->selectrow_array("SELECT m.file_id, d.name FROM module m JOIN dist d ON m.file_id=d.file_id WHERE m.name=?", {}, $args{module_or_dist})) {
+            last;
+        }
+    }
+    $file_id or return [404, "No such module/dist '$args{module_or_dist}'"];
+
+    my $res = App::lcpan::Cmd::dist_meta::handle_cmd(%args, dist=>$dist);
     return [412, $res->[1]] unless $res->[0] == 200;
     my $meta = $res->[2];
 
@@ -47,7 +61,7 @@ sub handle_cmd {
 }
 
 1;
-# ABSTRACT: Open the GitHub project page of a dist
+# ABSTRACT: Open the GitHub project page of a module/dist
 
 __END__
 
@@ -57,11 +71,11 @@ __END__
 
 =head1 NAME
 
-App::lcpan::Cmd::gh_open - Open the GitHub project page of a dist
+App::lcpan::Cmd::gh_open - Open the GitHub project page of a module/dist
 
 =head1 VERSION
 
-This document describes version 0.002 of App::lcpan::Cmd::gh_open (from Perl distribution App-lcpan-CmdBundle-gh), released on 2017-01-20.
+This document describes version 0.003 of App::lcpan::Cmd::gh_open (from Perl distribution App-lcpan-CmdBundle-gh), released on 2017-01-23.
 
 =head1 DESCRIPTION
 
@@ -72,7 +86,7 @@ This module handles the L<lcpan> subcommand C<gh-open>.
 
 =head2 handle_cmd(%args) -> [status, msg, result, meta]
 
-Open the GitHub project page of a dist.
+Open the GitHub project page of a module/dist.
 
 This function is not exported.
 
@@ -86,12 +100,14 @@ Location of your local CPAN mirror, e.g. /path/to/cpan.
 
 Defaults to C<~/cpan>.
 
-=item * B<dist>* => I<perl::distname>
-
 =item * B<index_name> => I<filename> (default: "index.db")
 
 Filename of index.
 
+=item * B<module_or_dist>* => I<str>
+
+Module or dist name.
+
 =back
 
 Returns an enveloped result (an array).
